@@ -5,6 +5,7 @@ from typing import List
 
 from boto3.session import Session
 from botocore.config import Config
+
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.parsers.fake_service_package import parse_fake_service_package
@@ -55,7 +56,10 @@ def parse_boto3_stubs_package(
     for service_package in result.service_packages:
         service_argument = Argument(
             "service_name",
-            TypeLiteral("", [service_package.service_name.boto3_name], inline=True),
+            TypeLiteral(
+                service_package.service_name.class_name + "Type",
+                [service_package.service_name.boto3_name],
+            ),
         )
         client_function = Function(
             name="client",
@@ -103,7 +107,10 @@ def parse_boto3_stubs_package(
             continue
         service_argument = Argument(
             "service_name",
-            TypeLiteral("", [service_package.service_name.boto3_name], inline=True),
+            TypeLiteral(
+                service_package.service_name.class_name + "Type",
+                [service_package.service_name.boto3_name],
+            ),
         )
         resource_function = Function(
             name="resource",
