@@ -2,6 +2,7 @@
 Boto3 client Waiter.
 """
 from botocore.waiter import Waiter as Boto3Waiter
+
 from mypy_boto3_builder.enums.service_module_name import ServiceModuleName
 from mypy_boto3_builder.import_helpers.import_string import ImportString
 from mypy_boto3_builder.service_name import ServiceName
@@ -24,16 +25,27 @@ class Waiter(ClassRecord):
         name: str,
         waiter_name: str,
         service_name: ServiceName,
-        docstring: str = "",
     ):
         super().__init__(
             name=name,
-            docstring=docstring,
             bases=[TypeClass(Boto3Waiter, alias="Boto3Waiter")],
         )
         self.waiter_name = waiter_name
         self.service_name = service_name
 
+    @property
+    def boto3_doc_link(self) -> str:
+        return self.service_name.get_boto3_doc_link("Waiter", self.waiter_name)
+
+    @property
+    def docstring(self) -> str:
+        return (
+            "[Show boto3 documentation]"
+            f"({self.boto3_doc_link})"
+            "[Show boto3-stubs documentation]"
+            f"({self.service_name.get_doc_link('waiters', self.name)})"
+        )
+
     def get_client_method(self) -> Method:
         return Method(
             name="get_waiter",
