@@ -10,6 +10,7 @@ from mypy_boto3_builder.constants import BOTO3_STUBS_STATIC_PATH
 from mypy_boto3_builder.structures.boto3_stubs_package import Boto3StubsPackage
 from mypy_boto3_builder.writers.utils import (
     blackify,
+    fix_pypi_headers,
     format_md,
     insert_md_toc,
     render_jinja2_template,
@@ -69,6 +70,7 @@ def write_boto3_stubs_package(
             content = blackify(content, file_path)
         if file_path.suffix == ".md":
             content = insert_md_toc(content)
+            content = fix_pypi_headers(content)
             content = format_md(content)
         if not file_path.exists() or file_path.read_text() != content:
             modified_paths.append(file_path)
